pub struct ProductSyntaxIndexV0 { /* private fields */ }Implementations
Sourceimpl ProductSyntaxIndexV0
impl ProductSyntaxIndexV0
pub fn new(source: &str, parsed: &ParseResult) -> Self
pub fn declarations(&self) -> &[ParserDeclarationSyntaxFactV0]
Sourcepub fn declarations_from_parse(
source: &str,
parsed: &ParseResult,
) -> Vec<ParserDeclarationSyntaxFactV0>
pub fn declarations_from_parse( source: &str, parsed: &ParseResult, ) -> Vec<ParserDeclarationSyntaxFactV0>
Project declarations from an existing parse without building the unrelated product-index families.
Sourcepub fn into_declarations(self) -> Vec<ParserDeclarationSyntaxFactV0>
pub fn into_declarations(self) -> Vec<ParserDeclarationSyntaxFactV0>
Consume the index and return its declaration projection without cloning declaration strings.